#ifndef __EDG_WORKLOAD_LOGGING_CLIENT_EVENTS_H__
#define __EDG_WORKLOAD_LOGGING_CLIENT_EVENTS_H__

/**
 * \brief contains definition of event type codes for use both by lbapi.h and dglog.h
 */

#ident "$Header: /cvs/glite/org.glite.lb.client-interface/interface/Attic/events.h.T,v 1.6.2.5 2007/08/01 15:47:29 akrenek Exp $"
/*

  !! Automatically generated file
  !! Do not edit, your changes will be discarded upon build
  !! Change the corresponding template file ../interface/events.h.T

*/

#include <sys/time.h>
#include <inttypes.h>

#include "glite/wmsutils/jobid/cjobid.h"
#include "glite/lb/context.h"
#include "glite/lb/notifid.h"

#include "glite/lb/padstruct.h"

#ifdef __cplusplus
extern "C" {
#endif

/**
 * \defgroup events Events
 * \brief All L&B event types.
 *
 *@{
 */

/**
 * Predefined type for ULM string 
 */
typedef char *edg_wll_LogLine;


/**
 * \typedef edg_wll_EventCode
 * Predefined event types 
 */
typedef enum _edg_wll_EventCode {
/** invalid code, e.g. uninitialized variable */
        EDG_WLL_EVENT_UNDEF = 0,
	EDG_WLL_EVENT_TRANSFER = 1,	/**< Start, success, or failure of job transfer to another component. */
	EDG_WLL_EVENT_ACCEPTED = 2,	/**< Accepting job (successful counterpart to Transfer). */
	EDG_WLL_EVENT_REFUSED = 3,	/**< Refusing job (unsuccessful counterpart to Transfer). */
	EDG_WLL_EVENT_ENQUEUED = 4,	/**< The job has been enqueued in an inter-component queue. */
	EDG_WLL_EVENT_DEQUEUED = 5,	/**< The job has been dequeued from an inter-component queue. */
	EDG_WLL_EVENT_HELPERCALL = 6,	/**< Helper component is called. */
	EDG_WLL_EVENT_HELPERRETURN = 7,	/**< Helper component is returning the control. */
	EDG_WLL_EVENT_RUNNING = 8,	/**< Job wrapper started. */
	EDG_WLL_EVENT_RESUBMISSION = 9,	/**< Result of resubmission decision. */
	EDG_WLL_EVENT_DONE = 10,	/**< Execution terminated (normally or abnormally). */
	EDG_WLL_EVENT_CANCEL = 11,	/**< Cancel operation has been attempted on the job. */
	EDG_WLL_EVENT_ABORT = 12,	/**< Job aborted by system. */
	EDG_WLL_EVENT_CLEAR = 13,	/**< Job cleared, output sandbox removed */
	EDG_WLL_EVENT_PURGE = 14,	/**< Job is purged from bookkepping server. */
	EDG_WLL_EVENT_MATCH = 15,	/**< Matching CE found. */
	EDG_WLL_EVENT_PENDING = 16,	/**< No matching CE found yet. */
	EDG_WLL_EVENT_REGJOB = 17,	/**< New job registration. */
	EDG_WLL_EVENT_CHKPT = 18,	/**< Application-specific checkpoint record. */
	EDG_WLL_EVENT_LISTENER = 19,	/**< Listening network port for interactive control. */
	EDG_WLL_EVENT_CURDESCR = 20,	/**< Current state of job processing (optional event). */
	EDG_WLL_EVENT_USERTAG = 21,	/**< User tag -- arbitrary name=value pair. */
	EDG_WLL_EVENT_CHANGEACL = 22,	/**< Management of ACL stored on bookkepping server. */
	EDG_WLL_EVENT_NOTIFICATION = 23,	/**< Management of notification service. */
	EDG_WLL_EVENT_RESOURCEUSAGE = 24,	/**< Resource (CPU, memory etc.) consumption. */
	EDG_WLL_EVENT_REALLYRUNNING = 25,	/**< User payload started. */
	EDG_WLL_EVENT_SUSPEND = 26,	/**< Job execution (queuing) was suspended. */
	EDG_WLL_EVENT_RESUME = 27,	/**< Job execution (queuing) was resumed. */
	EDG_WLL_EVENT_COLLECTIONSTATE = 28,	/**< State of the collection. */
/* new flesh PBS */
	EDG_WLL_EVENT_PBSQUEUED = 101,	/**< Job enqued */
	EDG_WLL_EVENT_PBSMATCH = 102,	/**< Scheduler created exec_host */
	EDG_WLL_EVENT_PBSPENDING = 103,	/**< Scheduler is not able to find exec_host, or some error occured */
	EDG_WLL_EVENT_PBSRUN = 104,	/**< Job attempted to be run by the logging component */
	EDG_WLL_EVENT_PBSRERUN = 105,	/**< Job rerun requested */
	EDG_WLL_EVENT_PBSDONE = 106,	/**< Job terminated */
	EDG_WLL_EVENT_PBSDEQUEUED = 107,	/**< Job dequeued */
	EDG_WLL_EVENT_PBSRESOURCEUSAGE = 108,	/**< Resources requested/consumed */
	EDG_WLL_EVENT_PBSERROR = 109,	/**< Any error occured */
/* new flesh Condor */
	EDG_WLL_EVENT_CONDORMATCH = 201,	/**< Job MATCHed */
	EDG_WLL_EVENT_CONDORREJECT = 202,	/**< Job REJECTed */
	EDG_WLL_EVENT_CONDORSHADOWSTARTED = 203,	/**< Condor Shadow Started */
	EDG_WLL_EVENT_CONDORSHADOWEXITED = 204,	/**< Condor Shadow Exited */
	EDG_WLL_EVENT_CONDORSTARTERSTARTED = 205,	/**< Condor Starter Started */
	EDG_WLL_EVENT_CONDORSTARTEREXITED = 206,	/**< Condor Starter Exited */
	EDG_WLL_EVENT_CONDORRESOURCEUSAGE = 207,	/**< Resources requested/consumed */
	EDG_WLL_EVENT_CONDORERROR = 208,	/**< Any Error occured */
        EDG_WLL_EVENT__LAST,	/**< last currently supported event code */
} edg_wll_EventCode;

/**
 * \fn edg_wll_EventCode edg_wll_StringToEvent(const char *name)
 * \param[in] name		a string event name (e.g. "JobTransfer")
 * \return corresponding numeric code (edg_wll_EventCode)
 * \brief convert a string event name to the corresponding numeric code
 */

extern edg_wll_EventCode edg_wll_StringToEvent(const char *name);

/**
 * \fn char *edg_wll_EventToString(edg_wll_EventCode event)
 * \param[in] event		an event numeric code (edg_wll_EventCode)
 * \return corresponding string (e.g. "JobTransfer")
 * \brief convert an event numeric code to the corresponding string
 */

extern char *edg_wll_EventToString(edg_wll_EventCode event);


/**
 * \typedef edg_wll_KeyNameCode
 * Predefined ULM key types
 */
typedef enum _edg_wll_KeyNameCode {
	UNDEFINED = 0,		/**< undefined */
	EDG_WLL_EVNT = 1,		/**< event type */
	ULM_DATE = 2,		/**< Time the event was generated. */
	ULM_ARR_DATE = 3,		/**< Time the event was stored into the bookkeeping server database. */
	ULM_HOST = 4,		/**< Hostname of the machine where the event was generated. */
	ULM_LVL = 5,		/**< Logging level (in the range from DEBUG to EMERGENCY). */
	EDG_WLL_COMMON_PRIORITY = 6,		/**< Message priority (yet 0 for asynchronous and 1 for synchronous transfers). */
	EDG_WLL_COMMON_JOBID = 7,		/**< Grid job id of the job the event belongs to. */
	EDG_WLL_COMMON_SEQCODE = 8,		/**< Sequence code assigned to the event. */
	EDG_WLL_COMMON_USER = 9,		/**< Identity (certificate subject) of the event sender. */
	EDG_WLL_COMMON_SOURCE = 10,		/**< Source (software component) which generated this event. */
	EDG_WLL_COMMON_SRC_INSTANCE = 11,		/**< Instance of source component (e.g. service communication endpoint). */
	EDG_WLL_TRANSFER_DESTINATION = 12,	/**< Destination where the job is being transfered to. */
	EDG_WLL_TRANSFER_DEST_HOST = 13,	/**< Hostname of server that takes over control of the job. */
	EDG_WLL_TRANSFER_DEST_INSTANCE = 14,	/**< Service (instance) that takes over control of the job. */
	EDG_WLL_TRANSFER_JOB = 15,	/**< Job description in receiver's language. */
	EDG_WLL_TRANSFER_RESULT = 16,	/**< Result code of the transfer attempt (START, OK, REFUSED or FAIL). */
	EDG_WLL_TRANSFER_REASON = 17,	/**< Detailed description of the transfer, especially reason of failure. */
	EDG_WLL_TRANSFER_DEST_JOBID = 18,	/**< Job id as assigned by the receiving software component. */
	EDG_WLL_ACCEPTED_FROM = 19,	/**< The software component  the job was received from. */
	EDG_WLL_ACCEPTED_FROM_HOST = 20,	/**< Hostname of the component the job was received from. */
	EDG_WLL_ACCEPTED_FROM_INSTANCE = 21,	/**< Instance of the component the job was received from. */
	EDG_WLL_ACCEPTED_LOCAL_JOBID = 22,	/**< New job id as assigned by the receiving component. */
	EDG_WLL_REFUSED_FROM = 23,	/**< The software component that tried to send the job. */
	EDG_WLL_REFUSED_FROM_HOST = 24,	/**< Hostname of the component that tried to send the job. */
	EDG_WLL_REFUSED_FROM_INSTANCE = 25,	/**< Instance of the component that tried to send the job. */
	EDG_WLL_REFUSED_REASON = 26,	/**< Description of the reason why the job was refused. */
	EDG_WLL_ENQUEUED_QUEUE = 27,	/**< Queue into which the job has been stored for retrieval by another component. */
	EDG_WLL_ENQUEUED_JOB = 28,	/**< Job description in the receiver's language. */
	EDG_WLL_ENQUEUED_RESULT = 29,	/**< Result code of the attempt to put job into the queue (START, OK, REFUSED or FAIL). */
	EDG_WLL_ENQUEUED_REASON = 30,	/**< Detailed description of the attempt to enqueue the job, especially the reason of failure. */
	EDG_WLL_DEQUEUED_QUEUE = 31,	/**< Name of the queue the job was obtained from. */
	EDG_WLL_DEQUEUED_LOCAL_JOBID = 32,	/**< New job id as assigned by the retreiving component. */
	EDG_WLL_HELPERCALL_HELPER_NAME = 33,	/**< Name of the called helper component. */
	EDG_WLL_HELPERCALL_HELPER_PARAMS = 34,	/**< Parameters of the call to the helper component. */
	EDG_WLL_HELPERCALL_SRC_ROLE = 35,	/**< The role the event sender is playing in the helper call (CALLING or CALLEE). */
	EDG_WLL_HELPERRETURN_HELPER_NAME = 36,	/**< Name of the called helper component. */
	EDG_WLL_HELPERRETURN_RETVAL = 37,	/**< Data returned by the call to the helper component. */
	EDG_WLL_HELPERRETURN_SRC_ROLE = 38,	/**< The role the event sender is playing in the helper call (CALLING or CALLEE). */
	EDG_WLL_RUNNING_NODE = 39,	/**< Worker node on which the job executable is being run. */
	EDG_WLL_RESUBMISSION_RESULT = 40,	/**< Result code of the resubmission decision (WILLRESUB or WONTRESUB or SHALLOW). */
	EDG_WLL_RESUBMISSION_REASON = 41,	/**< Reason why the job will or will not be resubmitted. */
	EDG_WLL_RESUBMISSION_TAG = 42,	/**< Value of the attribute on which the decision to resubmit the job was based. */
	EDG_WLL_DONE_STATUS_CODE = 43,	/**< Reason code for the termination of the job (OK, FAILED or CANCELLED). */
	EDG_WLL_DONE_REASON = 44,	/**< Detailed description why the job was terminated. */
	EDG_WLL_DONE_EXIT_CODE = 45,	/**< Exit code of the job's process. */
	EDG_WLL_CANCEL_STATUS_CODE = 46,	/**< Classification of the attempt to cancel the job (REQ, REFUSE, DONE or ABORT). */
	EDG_WLL_CANCEL_REASON = 47,	/**< Detailed description of the attempt to cancel the job, especially the reason of failure. */
	EDG_WLL_ABORT_REASON = 48,	/**< Reason why the job was aborted by the system. */
	EDG_WLL_CLEAR_REASON = 49,	/**< Description of the reason why the job was cleared and the output sandbox removed (USER, TIMEOUT or NOOUTPUT). */
	EDG_WLL_MATCH_DEST_ID = 50,	/**< Identification of the queue on the CE that the job could be send to. */
	EDG_WLL_PENDING_REASON = 51,	/**< Description why the matching CE for the job was not found (yet). */
	EDG_WLL_REGJOB_JDL = 52,	/**< Job description of the job being registered. */
	EDG_WLL_REGJOB_NS = 53,	/**< NetworkServer handling the newly registered job. */
	EDG_WLL_REGJOB_PARENT = 54,	/**< Grid job id of the parent job registering this new one. */
	EDG_WLL_REGJOB_JOBTYPE = 55,	/**< Type of the job being registered (SIMPLE, DAG, PARTITIONABLE or PARTITIONED). */
	EDG_WLL_REGJOB_NSUBJOBS = 56,	/**< Number of subjobs this job plans to spawn. */
	EDG_WLL_REGJOB_SEED = 57,	/**< Seed for subjob id generation. */
	EDG_WLL_CHKPT_TAG = 58,	/**< Application specific checkpoint tag. */
	EDG_WLL_CHKPT_CLASSAD = 59,	/**< Application specific checkpoint value. */
	EDG_WLL_LISTENER_SVC_NAME = 60,	/**< Name of the port instance for interactive job control. */
	EDG_WLL_LISTENER_SVC_HOST = 61,	/**< Hostname of the interactive job controller. */
	EDG_WLL_LISTENER_SVC_PORT = 62,	/**< Port number of the interactive job controller. */
	EDG_WLL_CURDESCR_DESCR = 63,	/**< Description of the current job transformation (output of the helper). */
	EDG_WLL_USERTAG_NAME = 64,	/**< Arbitrary user tag name. */
	EDG_WLL_USERTAG_VALUE = 65,	/**< Arbitrary user tag value. */
	EDG_WLL_CHANGEACL_USER_ID = 66,	/**< DN or VOMS parameter (in format VO:group). */
	EDG_WLL_CHANGEACL_USER_ID_TYPE = 67,	/**< Type of information given in user_id (DN or VOMS). */
	EDG_WLL_CHANGEACL_PERMISSION = 68,	/**< ACL permission to change (currently only READ). */
	EDG_WLL_CHANGEACL_PERMISSION_TYPE = 69,	/**< Type of permission requested ('allow', 'deny'). */
	EDG_WLL_CHANGEACL_OPERATION = 70,	/**< Operation requested to perform with ACL (add, remove). */
	EDG_WLL_NOTIFICATION_NOTIFID = 71,	/**< Notification id. */
	EDG_WLL_NOTIFICATION_OWNER = 72,	/**< Identification of the job owner (certificate subject). */
	EDG_WLL_NOTIFICATION_DEST_HOST = 73,	/**< Hostname the notification is sent to. */
	EDG_WLL_NOTIFICATION_DEST_PORT = 74,	/**< Port number the notification is sent to. */
	EDG_WLL_NOTIFICATION_EXPIRES = 75,	/**< When the notification expires */
	EDG_WLL_NOTIFICATION_JOBSTAT = 76,	/**< Status of the job (the notification content). */
	EDG_WLL_RESOURCEUSAGE_RESOURCE = 77,	/**< Resource's name. */
	EDG_WLL_RESOURCEUSAGE_QUANTITY = 78,	/**< Resources's quantity (how much). */
	EDG_WLL_RESOURCEUSAGE_UNIT = 79,	/**< Units (sec, kB, etc.). */
	EDG_WLL_REALLYRUNNING_WN_SEQ = 80,	/**< Sequence code on the worker node. */
	EDG_WLL_SUSPEND_REASON = 81,	/**< Reason for the suspend. */
	EDG_WLL_RESUME_REASON = 82,	/**< Reason for the resume. */
	EDG_WLL_COLLECTIONSTATE_STATE = 83,	/**< New collection state. */
	EDG_WLL_COLLECTIONSTATE_DONE_CODE = 84,	/**< In case of (state == Done) contains done code  */
	EDG_WLL_COLLECTIONSTATE_HISTOGRAM = 85,	/**< User readable histogram; useful for debugging. */
	EDG_WLL_COLLECTIONSTATE_CHILD = 86,	/**< JobId of subjob, which triggered the state change.	 */
	EDG_WLL_COLLECTIONSTATE_CHILD_EVENT = 87,	/**< Event which triggered the state change.	 */
	EDG_WLL_PBSQUEUED_QUEUE = 88,	/**< Queue name */
	EDG_WLL_PBSQUEUED_OWNER = 89,	/**< Job owner */
	EDG_WLL_PBSQUEUED_NAME = 90,	/**< Job name */
	EDG_WLL_PBSMATCH_DEST_HOST = 91,	/**< Aka exec_host */
	EDG_WLL_PBSPENDING_REASON = 92,	/**< Reasons of job pendation or errors */
	EDG_WLL_PBSRUN_SCHEDULER = 93,	/**< Scheduler ID */
	EDG_WLL_PBSRUN_DEST_HOST = 94,	/**< Where to run the job */
	EDG_WLL_PBSRUN_PID = 95,	/**< Actual process ID */
	EDG_WLL_PBSDONE_EXIT_STATUS = 96,	/**< Exit status */
	EDG_WLL_PBSRESOURCEUSAGE_USAGE = 97,	/**< Type of record */
	EDG_WLL_PBSRESOURCEUSAGE_NAME = 98,	/**< Name of resource */
	EDG_WLL_PBSRESOURCEUSAGE_QUANTITY = 99,	/**< The quantity */
	EDG_WLL_PBSRESOURCEUSAGE_UNIT = 100,	/**< Units (sec, kB, etc.) */
	EDG_WLL_PBSERROR_ERROR_DESC = 101,	/**< Error reason */
	EDG_WLL_CONDORMATCH_OWNER = 102,	/**< Owner */
	EDG_WLL_CONDORMATCH_DEST_HOST = 103,	/**< Matched host */
	EDG_WLL_CONDORMATCH_PREEMPTING = 104,	/**< Preempting */
	EDG_WLL_CONDORREJECT_OWNER = 105,	/**< Owner */
	EDG_WLL_CONDORREJECT_STATUS_CODE = 106,	/**< Reason code for the rejection of the job */
	EDG_WLL_CONDORSHADOWSTARTED_SHADOW_HOST = 107,	/**< Shadow host */
	EDG_WLL_CONDORSHADOWSTARTED_SHADOW_PORT = 108,	/**< Shadow port */
	EDG_WLL_CONDORSHADOWSTARTED_SHADOW_PID = 109,	/**< PID of shadow process */
	EDG_WLL_CONDORSHADOWSTARTED_SHADOW_STATUS = 110,	/**< Shadow status */
	EDG_WLL_CONDORSHADOWEXITED_SHADOW_PID = 111,	/**< PID of shadow process */
	EDG_WLL_CONDORSHADOWEXITED_SHADOW_EXIT_STATUS = 112,	/**< Exit status of shadow process */
	EDG_WLL_CONDORSTARTERSTARTED_STARTER_PID = 113,	/**< PID of starter process */
	EDG_WLL_CONDORSTARTERSTARTED_UNIVERSE = 114,	/**< Condor Universe */
	EDG_WLL_CONDORSTARTEREXITED_STARTER_PID = 115,	/**< PID of starter process */
	EDG_WLL_CONDORSTARTEREXITED_STARTER_EXIT_STATUS = 116,	/**< Exit status of starter process */
	EDG_WLL_CONDORSTARTEREXITED_JOB_PID = 117,	/**< PID of running job */
	EDG_WLL_CONDORSTARTEREXITED_JOB_EXIT_STATUS = 118,	/**< Job exit status */
	EDG_WLL_CONDORRESOURCEUSAGE_USAGE = 119,	/**< Type of record */
	EDG_WLL_CONDORRESOURCEUSAGE_NAME = 120,	/**< Name of resource */
	EDG_WLL_CONDORRESOURCEUSAGE_QUANTITY = 121,	/**< The quantity */
	EDG_WLL_CONDORRESOURCEUSAGE_UNIT = 122,	/**< Units (sec, kB, etc.) */
	EDG_WLL_CONDORERROR_ERROR_DESC = 123,	/**< Error reason */
	EDG_WLL_INTERNAL_TYPE,		/**< internal message type */
} edg_wll_KeyNameCode;

/**
 * \fn edg_wll_KeyNameCode edg_wll_StringToKeyName(const char *name)
 * \param[in] name		a string ULM key name (e.g. "DG.JOB.TRANSFER.DEST")
 * \return corresponding numeric code (edg_wll_KeyNameCode)
 * \brief convert a string ULM key name to the corresponding numeric code
 */

extern edg_wll_KeyNameCode edg_wll_StringToKeyName(const char *name);

/**
 * \fn char *edg_wll_KeyNameToString(edg_wll_KeyNameCode key)
 * \param[in] key		a ULM key name numeric code (edg_wll_KeyNameCode)
 * \return corresponding string (e.g. "DG.JOB.TRANSFER.DEST")
 * \brief convert a ULM key name numeric code to the corresponding string
 */

extern char *edg_wll_KeyNameToString(edg_wll_KeyNameCode key);


/**
 * Predefined _code_ types and
 * related StringTo_code and _code_ToString function prototypes
 */

/**
 * \enum edg_wll_Level
 * Level codes 
 */
enum edg_wll_Level {
	EDG_WLL_LEVEL_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_LEVEL_EMERGENCY,	/**< emergency */ 
	EDG_WLL_LEVEL_ALERT,	/**< alert */ 
	EDG_WLL_LEVEL_ERROR,	/**< error */ 
	EDG_WLL_LEVEL_WARNING,	/**< warning */ 
	EDG_WLL_LEVEL_AUTH,	/**< authentication */ 
	EDG_WLL_LEVEL_SECURITY,	/**< security */ 
	EDG_WLL_LEVEL_USAGE,	/**< usage */ 
	EDG_WLL_LEVEL_SYSTEM,	/**< system */ 
	EDG_WLL_LEVEL_IMPORTANT,	/**< important */ 
	EDG_WLL_LEVEL_DEBUG,	/**< debug */ 
};

/**
 * \fn enum edg_wll_Level edg_wll_StringToLevel(const char *name);
 * \param[in] name		a string representing Level code (e.g. "ALERT")
 * \return corresponding numeric code (enum edg_wll_Level)
 * \brief converts a string Level code to corresponding numeric code
 */
extern enum edg_wll_Level edg_wll_StringToLevel(const char *name);

/**
 * \fn char *edg_wll_LevelToString(enum edg_wll_Level code);
 * \param[in] code		a Level numeric code (enum edg_wll_Level)
 * \return corresponding string (e.g. "ALERT")
 * \brief converts a Level numeric code to corresponding string
 */
extern char *edg_wll_LevelToString(enum edg_wll_Level code);


/**
 * \enum edg_wll_TransferResult
 * Result codes of the Transfer event
 */
enum edg_wll_TransferResult {
	EDG_WLL_TRANSFER_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_TRANSFER_START,	/**< The sending component has started or is about to start the transfer. */ 
	EDG_WLL_TRANSFER_OK,	/**< The job was sent successfully. */ 
	EDG_WLL_TRANSFER_REFUSED,	/**< The job was refused by the other component. */ 
	EDG_WLL_TRANSFER_FAIL,	/**< The transfer failed for other reason than explicit refusal (eg. network timeout). */ 
};

/**
 * \fn enum edg_wll_TransferResult edg_wll_StringToTransferResult(const char *name);
 * \param[in] name		a string representing Transfer Result code (e.g. "OK")
 * \return corresponding numeric code (enum edg_wll_TransferResult)
 * \brief converts a string Transfer Result code to corresponding numeric code
 */
extern enum edg_wll_TransferResult edg_wll_StringToTransferResult(const char *name);

/**
 * \fn char *edg_wll_TransferResultToString(enum edg_wll_TransferResult code);
 * \param[in] code		a Transfer Result numeric code (enum edg_wll_TransferResult)
 * \return corresponding string (e.g. "OK")
 * \brief converts a Transfer Result numeric code to corresponding string
 */
extern char *edg_wll_TransferResultToString(enum edg_wll_TransferResult code);


/**
 * \enum edg_wll_EnQueuedResult
 * Result codes of the EnQueued event
 */
enum edg_wll_EnQueuedResult {
	EDG_WLL_ENQUEUED_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_ENQUEUED_START,	/**< The sending component has started or is about to start enqueuing the job. */ 
	EDG_WLL_ENQUEUED_OK,	/**< The job was enqueued successfully. */ 
	EDG_WLL_ENQUEUED_REFUSED,	/**< The job was refused by the other component. */ 
	EDG_WLL_ENQUEUED_FAIL,	/**< The transfer failed for other reason than explicit refusal. */ 
};

/**
 * \fn enum edg_wll_EnQueuedResult edg_wll_StringToEnQueuedResult(const char *name);
 * \param[in] name		a string representing EnQueued Result code (e.g. "OK")
 * \return corresponding numeric code (enum edg_wll_EnQueuedResult)
 * \brief converts a string EnQueued Result code to corresponding numeric code
 */
extern enum edg_wll_EnQueuedResult edg_wll_StringToEnQueuedResult(const char *name);

/**
 * \fn char *edg_wll_EnQueuedResultToString(enum edg_wll_EnQueuedResult code);
 * \param[in] code		a EnQueued Result numeric code (enum edg_wll_EnQueuedResult)
 * \return corresponding string (e.g. "OK")
 * \brief converts a EnQueued Result numeric code to corresponding string
 */
extern char *edg_wll_EnQueuedResultToString(enum edg_wll_EnQueuedResult code);


/**
 * \enum edg_wll_HelperCallSrc_role
 * Src_role codes of the HelperCall event
 */
enum edg_wll_HelperCallSrc_role {
	EDG_WLL_HELPERCALL_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_HELPERCALL_CALLING,	/**< The logging component is caller. */ 
	EDG_WLL_HELPERCALL_CALLED,	/**< The logging component is callee. */ 
};

/**
 * \fn enum edg_wll_HelperCallSrc_role edg_wll_StringToHelperCallSrc_role(const char *name);
 * \param[in] name		a string representing HelperCall Src_role code (e.g. "CALLED")
 * \return corresponding numeric code (enum edg_wll_HelperCallSrc_role)
 * \brief converts a string HelperCall Src_role code to corresponding numeric code
 */
extern enum edg_wll_HelperCallSrc_role edg_wll_StringToHelperCallSrc_role(const char *name);

/**
 * \fn char *edg_wll_HelperCallSrc_roleToString(enum edg_wll_HelperCallSrc_role code);
 * \param[in] code		a HelperCall Src_role numeric code (enum edg_wll_HelperCallSrc_role)
 * \return corresponding string (e.g. "CALLED")
 * \brief converts a HelperCall Src_role numeric code to corresponding string
 */
extern char *edg_wll_HelperCallSrc_roleToString(enum edg_wll_HelperCallSrc_role code);


/**
 * \enum edg_wll_HelperReturnSrc_role
 * Src_role codes of the HelperReturn event
 */
enum edg_wll_HelperReturnSrc_role {
	EDG_WLL_HELPERRETURN_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_HELPERRETURN_CALLING,	/**< The logging component is caller. */ 
	EDG_WLL_HELPERRETURN_CALLED,	/**< The logging component is callee. */ 
};

/**
 * \fn enum edg_wll_HelperReturnSrc_role edg_wll_StringToHelperReturnSrc_role(const char *name);
 * \param[in] name		a string representing HelperReturn Src_role code (e.g. "CALLED")
 * \return corresponding numeric code (enum edg_wll_HelperReturnSrc_role)
 * \brief converts a string HelperReturn Src_role code to corresponding numeric code
 */
extern enum edg_wll_HelperReturnSrc_role edg_wll_StringToHelperReturnSrc_role(const char *name);

/**
 * \fn char *edg_wll_HelperReturnSrc_roleToString(enum edg_wll_HelperReturnSrc_role code);
 * \param[in] code		a HelperReturn Src_role numeric code (enum edg_wll_HelperReturnSrc_role)
 * \return corresponding string (e.g. "CALLED")
 * \brief converts a HelperReturn Src_role numeric code to corresponding string
 */
extern char *edg_wll_HelperReturnSrc_roleToString(enum edg_wll_HelperReturnSrc_role code);


/**
 * \enum edg_wll_ResubmissionResult
 * Result codes of the Resubmission event
 */
enum edg_wll_ResubmissionResult {
	EDG_WLL_RESUBMISSION_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_RESUBMISSION_WILLRESUB,	/**< The job will be resubmitted (deep resubmission). */ 
	EDG_WLL_RESUBMISSION_WONTRESUB,	/**< The job will not be resubmitted. */ 
	EDG_WLL_RESUBMISSION_SHALLOW,	/**< Shallow resubmission (user payload has not started yet) */ 
};

/**
 * \fn enum edg_wll_ResubmissionResult edg_wll_StringToResubmissionResult(const char *name);
 * \param[in] name		a string representing Resubmission Result code (e.g. "WONTRESUB")
 * \return corresponding numeric code (enum edg_wll_ResubmissionResult)
 * \brief converts a string Resubmission Result code to corresponding numeric code
 */
extern enum edg_wll_ResubmissionResult edg_wll_StringToResubmissionResult(const char *name);

/**
 * \fn char *edg_wll_ResubmissionResultToString(enum edg_wll_ResubmissionResult code);
 * \param[in] code		a Resubmission Result numeric code (enum edg_wll_ResubmissionResult)
 * \return corresponding string (e.g. "WONTRESUB")
 * \brief converts a Resubmission Result numeric code to corresponding string
 */
extern char *edg_wll_ResubmissionResultToString(enum edg_wll_ResubmissionResult code);


/**
 * \enum edg_wll_DoneStatus_code
 * Status_code codes of the Done event
 */
enum edg_wll_DoneStatus_code {
	EDG_WLL_DONE_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_DONE_OK,	/**< The job terminated by itself. */ 
	EDG_WLL_DONE_FAILED,	/**< The job disappeared from LRMS. */ 
	EDG_WLL_DONE_CANCELLED,	/**< The job was cancelled by user request. */ 
};

/**
 * \fn enum edg_wll_DoneStatus_code edg_wll_StringToDoneStatus_code(const char *name);
 * \param[in] name		a string representing Done Status_code code (e.g. "FAILED")
 * \return corresponding numeric code (enum edg_wll_DoneStatus_code)
 * \brief converts a string Done Status_code code to corresponding numeric code
 */
extern enum edg_wll_DoneStatus_code edg_wll_StringToDoneStatus_code(const char *name);

/**
 * \fn char *edg_wll_DoneStatus_codeToString(enum edg_wll_DoneStatus_code code);
 * \param[in] code		a Done Status_code numeric code (enum edg_wll_DoneStatus_code)
 * \return corresponding string (e.g. "FAILED")
 * \brief converts a Done Status_code numeric code to corresponding string
 */
extern char *edg_wll_DoneStatus_codeToString(enum edg_wll_DoneStatus_code code);


/**
 * \enum edg_wll_CancelStatus_code
 * Status_code codes of the Cancel event
 */
enum edg_wll_CancelStatus_code {
	EDG_WLL_CANCEL_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_CANCEL_REQ,	/**< The request was acknowledged. */ 
	EDG_WLL_CANCEL_REFUSE,	/**< The request was declined by this component. */ 
	EDG_WLL_CANCEL_DONE,	/**< The request was completed by whole WMS. */ 
	EDG_WLL_CANCEL_ABORT,	/**< The request was refused by whole WMS. */ 
};

/**
 * \fn enum edg_wll_CancelStatus_code edg_wll_StringToCancelStatus_code(const char *name);
 * \param[in] name		a string representing Cancel Status_code code (e.g. "REFUSE")
 * \return corresponding numeric code (enum edg_wll_CancelStatus_code)
 * \brief converts a string Cancel Status_code code to corresponding numeric code
 */
extern enum edg_wll_CancelStatus_code edg_wll_StringToCancelStatus_code(const char *name);

/**
 * \fn char *edg_wll_CancelStatus_codeToString(enum edg_wll_CancelStatus_code code);
 * \param[in] code		a Cancel Status_code numeric code (enum edg_wll_CancelStatus_code)
 * \return corresponding string (e.g. "REFUSE")
 * \brief converts a Cancel Status_code numeric code to corresponding string
 */
extern char *edg_wll_CancelStatus_codeToString(enum edg_wll_CancelStatus_code code);


/**
 * \enum edg_wll_ClearReason
 * Reason codes of the Clear event
 */
enum edg_wll_ClearReason {
	EDG_WLL_CLEAR_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_CLEAR_USER,	/**< User retrieved output sandbox. */ 
	EDG_WLL_CLEAR_TIMEOUT,	/**< Timed out, resource forced purge of the sandbox. */ 
	EDG_WLL_CLEAR_NOOUTPUT,	/**< No output was generated. */ 
};

/**
 * \fn enum edg_wll_ClearReason edg_wll_StringToClearReason(const char *name);
 * \param[in] name		a string representing Clear Reason code (e.g. "TIMEOUT")
 * \return corresponding numeric code (enum edg_wll_ClearReason)
 * \brief converts a string Clear Reason code to corresponding numeric code
 */
extern enum edg_wll_ClearReason edg_wll_StringToClearReason(const char *name);

/**
 * \fn char *edg_wll_ClearReasonToString(enum edg_wll_ClearReason code);
 * \param[in] code		a Clear Reason numeric code (enum edg_wll_ClearReason)
 * \return corresponding string (e.g. "TIMEOUT")
 * \brief converts a Clear Reason numeric code to corresponding string
 */
extern char *edg_wll_ClearReasonToString(enum edg_wll_ClearReason code);


/**
 * \enum edg_wll_RegJobJobtype
 * Jobtype codes of the RegJob event
 */
enum edg_wll_RegJobJobtype {
	EDG_WLL_REGJOB_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_REGJOB_SIMPLE,	/**< The job is simple job. */ 
	EDG_WLL_REGJOB_DAG,	/**< The job is dag (containing static set of subjobs). */ 
	EDG_WLL_REGJOB_PARTITIONABLE,	/**< The job is partitionable (may become partitioned). */ 
	EDG_WLL_REGJOB_PARTITIONED,	/**< The job is partitioned (dynamically created dag). */ 
	EDG_WLL_REGJOB_COLLECTION,	/**< The job is collection (containing static set of subjobs). */ 
	EDG_WLL_REGJOB_PBS,	/**< PBS job */ 
	EDG_WLL_REGJOB_CONDOR,	/**< Condor job */ 
};

/**
 * \fn enum edg_wll_RegJobJobtype edg_wll_StringToRegJobJobtype(const char *name);
 * \param[in] name		a string representing RegJob Jobtype code (e.g. "DAG")
 * \return corresponding numeric code (enum edg_wll_RegJobJobtype)
 * \brief converts a string RegJob Jobtype code to corresponding numeric code
 */
extern enum edg_wll_RegJobJobtype edg_wll_StringToRegJobJobtype(const char *name);

/**
 * \fn char *edg_wll_RegJobJobtypeToString(enum edg_wll_RegJobJobtype code);
 * \param[in] code		a RegJob Jobtype numeric code (enum edg_wll_RegJobJobtype)
 * \return corresponding string (e.g. "DAG")
 * \brief converts a RegJob Jobtype numeric code to corresponding string
 */
extern char *edg_wll_RegJobJobtypeToString(enum edg_wll_RegJobJobtype code);


/**
 * \enum edg_wll_PBSResourceUsageUsage
 * Usage codes of the PBSResourceUsage event
 */
enum edg_wll_PBSResourceUsageUsage {
	EDG_WLL_PBSRESOURCEUSAGE_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_PBSRESOURCEUSAGE_REQUESTED,	/**< Requested value */ 
	EDG_WLL_PBSRESOURCEUSAGE_USED,	/**< Consumed quantity */ 
};

/**
 * \fn enum edg_wll_PBSResourceUsageUsage edg_wll_StringToPBSResourceUsageUsage(const char *name);
 * \param[in] name		a string representing PBSResourceUsage Usage code (e.g. "USED")
 * \return corresponding numeric code (enum edg_wll_PBSResourceUsageUsage)
 * \brief converts a string PBSResourceUsage Usage code to corresponding numeric code
 */
extern enum edg_wll_PBSResourceUsageUsage edg_wll_StringToPBSResourceUsageUsage(const char *name);

/**
 * \fn char *edg_wll_PBSResourceUsageUsageToString(enum edg_wll_PBSResourceUsageUsage code);
 * \param[in] code		a PBSResourceUsage Usage numeric code (enum edg_wll_PBSResourceUsageUsage)
 * \return corresponding string (e.g. "USED")
 * \brief converts a PBSResourceUsage Usage numeric code to corresponding string
 */
extern char *edg_wll_PBSResourceUsageUsageToString(enum edg_wll_PBSResourceUsageUsage code);


/**
 * \enum edg_wll_CondorRejectStatus_code
 * Status_code codes of the CondorReject event
 */
enum edg_wll_CondorRejectStatus_code {
	EDG_WLL_CONDORREJECT_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_CONDORREJECT_NOMATCH,	/**< No match found */ 
	EDG_WLL_CONDORREJECT_OTHER,	/**< Other reason */ 
};

/**
 * \fn enum edg_wll_CondorRejectStatus_code edg_wll_StringToCondorRejectStatus_code(const char *name);
 * \param[in] name		a string representing CondorReject Status_code code (e.g. "OTHER")
 * \return corresponding numeric code (enum edg_wll_CondorRejectStatus_code)
 * \brief converts a string CondorReject Status_code code to corresponding numeric code
 */
extern enum edg_wll_CondorRejectStatus_code edg_wll_StringToCondorRejectStatus_code(const char *name);

/**
 * \fn char *edg_wll_CondorRejectStatus_codeToString(enum edg_wll_CondorRejectStatus_code code);
 * \param[in] code		a CondorReject Status_code numeric code (enum edg_wll_CondorRejectStatus_code)
 * \return corresponding string (e.g. "OTHER")
 * \brief converts a CondorReject Status_code numeric code to corresponding string
 */
extern char *edg_wll_CondorRejectStatus_codeToString(enum edg_wll_CondorRejectStatus_code code);


/**
 * \enum edg_wll_CondorResourceUsageUsage
 * Usage codes of the CondorResourceUsage event
 */
enum edg_wll_CondorResourceUsageUsage {
	EDG_WLL_CONDORRESOURCEUSAGE_UNDEFINED,	/**< undefined code */ 
	EDG_WLL_CONDORRESOURCEUSAGE_REQUESTED,	/**< Requested value */ 
	EDG_WLL_CONDORRESOURCEUSAGE_USED,	/**< Consumed quantity */ 
};

/**
 * \fn enum edg_wll_CondorResourceUsageUsage edg_wll_StringToCondorResourceUsageUsage(const char *name);
 * \param[in] name		a string representing CondorResourceUsage Usage code (e.g. "USED")
 * \return corresponding numeric code (enum edg_wll_CondorResourceUsageUsage)
 * \brief converts a string CondorResourceUsage Usage code to corresponding numeric code
 */
extern enum edg_wll_CondorResourceUsageUsage edg_wll_StringToCondorResourceUsageUsage(const char *name);

/**
 * \fn char *edg_wll_CondorResourceUsageUsageToString(enum edg_wll_CondorResourceUsageUsage code);
 * \param[in] code		a CondorResourceUsage Usage numeric code (enum edg_wll_CondorResourceUsageUsage)
 * \return corresponding string (e.g. "USED")
 * \brief converts a CondorResourceUsage Usage numeric code to corresponding string
 */
extern char *edg_wll_CondorResourceUsageUsageToString(enum edg_wll_CondorResourceUsageUsage code);



/**
 * common fields of all event types: 
 */

#define _EDG_WLL_EVENT_COMMON \
	edg_wll_EventCode		type;\
	struct timeval		timestamp;	\
	struct timeval		arrived;	\
	char *		host;	\
	int		level;	\
	int		priority;	\
	edg_wlc_JobId		jobId;	\
	char *		seqcode;	\
	char *		user;	\
	edg_wll_Source		source;	\
	char *		src_instance;	\


/**
 * \typedef edg_wll_AnyEvent
 * common structure definition contained in all types of the events
 */
typedef struct _edg_wll_AnyEvent {
_EDG_WLL_EVENT_COMMON
} edg_wll_AnyEvent;


/**
 *  Event types specific structures: 
 */

/**
* \typedef edg_wll_TransferEvent
* structure definition for Transfer event 
*/
typedef struct _edg_wll_TransferEvent {
_EDG_WLL_EVENT_COMMON
	edg_wll_Source	destination;	/**< Destination where the job is being transfered to. */
	char *	dest_host;	/**< Hostname of server that takes over control of the job. */
	char *	dest_instance;	/**< Service (instance) that takes over control of the job. */
	char *	job;	/**< Job description in receiver's language. */
	enum edg_wll_TransferResult	result;	/**< Result code of the transfer attempt (START, OK, REFUSED or FAIL). */
	char *	reason;	/**< Detailed description of the transfer, especially reason of failure. */
	char *	dest_jobid;	/**< Job id as assigned by the receiving software component. */
} edg_wll_TransferEvent;

/**
* \typedef edg_wll_AcceptedEvent
* structure definition for Accepted event 
*/
typedef struct _edg_wll_AcceptedEvent {
_EDG_WLL_EVENT_COMMON
	edg_wll_Source	from;	/**< The software component  the job was received from. */
	char *	from_host;	/**< Hostname of the component the job was received from. */
	char *	from_instance;	/**< Instance of the component the job was received from. */
	char *	local_jobid;	/**< New job id as assigned by the receiving component. */
} edg_wll_AcceptedEvent;

/**
* \typedef edg_wll_RefusedEvent
* structure definition for Refused event 
*/
typedef struct _edg_wll_RefusedEvent {
_EDG_WLL_EVENT_COMMON
	edg_wll_Source	from;	/**< The software component that tried to send the job. */
	char *	from_host;	/**< Hostname of the component that tried to send the job. */
	char *	from_instance;	/**< Instance of the component that tried to send the job. */
	char *	reason;	/**< Description of the reason why the job was refused. */
} edg_wll_RefusedEvent;

/**
* \typedef edg_wll_EnQueuedEvent
* structure definition for EnQueued event 
*/
typedef struct _edg_wll_EnQueuedEvent {
_EDG_WLL_EVENT_COMMON
	char *	queue;	/**< Queue into which the job has been stored for retrieval by another component. */
	char *	job;	/**< Job description in the receiver's language. */
	enum edg_wll_EnQueuedResult	result;	/**< Result code of the attempt to put job into the queue (START, OK, REFUSED or FAIL). */
	char *	reason;	/**< Detailed description of the attempt to enqueue the job, especially the reason of failure. */
} edg_wll_EnQueuedEvent;

/**
* \typedef edg_wll_DeQueuedEvent
* structure definition for DeQueued event 
*/
typedef struct _edg_wll_DeQueuedEvent {
_EDG_WLL_EVENT_COMMON
	char *	queue;	/**< Name of the queue the job was obtained from. */
	char *	local_jobid;	/**< New job id as assigned by the retreiving component. */
} edg_wll_DeQueuedEvent;

/**
* \typedef edg_wll_HelperCallEvent
* structure definition for HelperCall event 
*/
typedef struct _edg_wll_HelperCallEvent {
_EDG_WLL_EVENT_COMMON
	char *	helper_name;	/**< Name of the called helper component. */
	char *	helper_params;	/**< Parameters of the call to the helper component. */
	enum edg_wll_HelperCallSrc_role	src_role;	/**< The role the event sender is playing in the helper call (CALLING or CALLEE). */
} edg_wll_HelperCallEvent;

/**
* \typedef edg_wll_HelperReturnEvent
* structure definition for HelperReturn event 
*/
typedef struct _edg_wll_HelperReturnEvent {
_EDG_WLL_EVENT_COMMON
	char *	helper_name;	/**< Name of the called helper component. */
	char *	retval;	/**< Data returned by the call to the helper component. */
	enum edg_wll_HelperReturnSrc_role	src_role;	/**< The role the event sender is playing in the helper call (CALLING or CALLEE). */
} edg_wll_HelperReturnEvent;

/**
* \typedef edg_wll_RunningEvent
* structure definition for Running event 
*/
typedef struct _edg_wll_RunningEvent {
_EDG_WLL_EVENT_COMMON
	char *	node;	/**< Worker node on which the job executable is being run. */
} edg_wll_RunningEvent;

/**
* \typedef edg_wll_ResubmissionEvent
* structure definition for Resubmission event 
*/
typedef struct _edg_wll_ResubmissionEvent {
_EDG_WLL_EVENT_COMMON
	enum edg_wll_ResubmissionResult	result;	/**< Result code of the resubmission decision (WILLRESUB or WONTRESUB or SHALLOW). */
	char *	reason;	/**< Reason why the job will or will not be resubmitted. */
	char *	tag;	/**< Value of the attribute on which the decision to resubmit the job was based. */
} edg_wll_ResubmissionEvent;

/**
* \typedef edg_wll_DoneEvent
* structure definition for Done event 
*/
typedef struct _edg_wll_DoneEvent {
_EDG_WLL_EVENT_COMMON
	enum edg_wll_DoneStatus_code	status_code;	/**< Reason code for the termination of the job (OK, FAILED or CANCELLED). */
	char *	reason;	/**< Detailed description why the job was terminated. */
	int	exit_code;	/**< Exit code of the job's process. */
} edg_wll_DoneEvent;

/**
* \typedef edg_wll_CancelEvent
* structure definition for Cancel event 
*/
typedef struct _edg_wll_CancelEvent {
_EDG_WLL_EVENT_COMMON
	enum edg_wll_CancelStatus_code	status_code;	/**< Classification of the attempt to cancel the job (REQ, REFUSE, DONE or ABORT). */
	char *	reason;	/**< Detailed description of the attempt to cancel the job, especially the reason of failure. */
} edg_wll_CancelEvent;

/**
* \typedef edg_wll_AbortEvent
* structure definition for Abort event 
*/
typedef struct _edg_wll_AbortEvent {
_EDG_WLL_EVENT_COMMON
	char *	reason;	/**< Reason why the job was aborted by the system. */
} edg_wll_AbortEvent;

/**
* \typedef edg_wll_ClearEvent
* structure definition for Clear event 
*/
typedef struct _edg_wll_ClearEvent {
_EDG_WLL_EVENT_COMMON
	enum edg_wll_ClearReason	reason;	/**< Description of the reason why the job was cleared and the output sandbox removed (USER, TIMEOUT or NOOUTPUT). */
} edg_wll_ClearEvent;

/**
* \typedef edg_wll_PurgeEvent
* structure definition for Purge event 
*/
typedef struct _edg_wll_PurgeEvent {
_EDG_WLL_EVENT_COMMON
} edg_wll_PurgeEvent;

/**
* \typedef edg_wll_MatchEvent
* structure definition for Match event 
*/
typedef struct _edg_wll_MatchEvent {
_EDG_WLL_EVENT_COMMON
	char *	dest_id;	/**< Identification of the queue on the CE that the job could be send to. */
} edg_wll_MatchEvent;

/**
* \typedef edg_wll_PendingEvent
* structure definition for Pending event 
*/
typedef struct _edg_wll_PendingEvent {
_EDG_WLL_EVENT_COMMON
	char *	reason;	/**< Description why the matching CE for the job was not found (yet). */
} edg_wll_PendingEvent;

/**
* \typedef edg_wll_RegJobEvent
* structure definition for RegJob event 
*/
typedef struct _edg_wll_RegJobEvent {
_EDG_WLL_EVENT_COMMON
	char *	jdl;	/**< Job description of the job being registered. */
	char *	ns;	/**< NetworkServer handling the newly registered job. */
	edg_wlc_JobId	parent;	/**< Grid job id of the parent job registering this new one. */
	enum edg_wll_RegJobJobtype	jobtype;	/**< Type of the job being registered (SIMPLE, DAG, PARTITIONABLE or PARTITIONED). */
	int	nsubjobs;	/**< Number of subjobs this job plans to spawn. */
	char *	seed;	/**< Seed for subjob id generation. */
} edg_wll_RegJobEvent;

/**
* \typedef edg_wll_ChkptEvent
* structure definition for Chkpt event 
*/
typedef struct _edg_wll_ChkptEvent {
_EDG_WLL_EVENT_COMMON
	char *	tag;	/**< Application specific checkpoint tag. */
	char *	classad;	/**< Application specific checkpoint value. */
} edg_wll_ChkptEvent;

/**
* \typedef edg_wll_ListenerEvent
* structure definition for Listener event 
*/
typedef struct _edg_wll_ListenerEvent {
_EDG_WLL_EVENT_COMMON
	char *	svc_name;	/**< Name of the port instance for interactive job control. */
	char *	svc_host;	/**< Hostname of the interactive job controller. */
	uint16_t	svc_port;	/**< Port number of the interactive job controller. */
} edg_wll_ListenerEvent;

/**
* \typedef edg_wll_CurDescrEvent
* structure definition for CurDescr event 
*/
typedef struct _edg_wll_CurDescrEvent {
_EDG_WLL_EVENT_COMMON
	char *	descr;	/**< Description of the current job transformation (output of the helper). */
} edg_wll_CurDescrEvent;

/**
* \typedef edg_wll_UserTagEvent
* structure definition for UserTag event 
*/
typedef struct _edg_wll_UserTagEvent {
_EDG_WLL_EVENT_COMMON
	char *	name;	/**< Arbitrary user tag name. */
	char *	value;	/**< Arbitrary user tag value. */
} edg_wll_UserTagEvent;

/**
* \typedef edg_wll_ChangeACLEvent
* structure definition for ChangeACL event 
*/
typedef struct _edg_wll_ChangeACLEvent {
_EDG_WLL_EVENT_COMMON
	char *	user_id;	/**< DN or VOMS parameter (in format VO:group). */
	int	user_id_type;	/**< Type of information given in user_id (DN or VOMS). */
	int	permission;	/**< ACL permission to change (currently only READ). */
	int	permission_type;	/**< Type of permission requested ('allow', 'deny'). */
	int	operation;	/**< Operation requested to perform with ACL (add, remove). */
} edg_wll_ChangeACLEvent;

/**
* \typedef edg_wll_NotificationEvent
* structure definition for Notification event 
*/
typedef struct _edg_wll_NotificationEvent {
_EDG_WLL_EVENT_COMMON
	edg_wll_NotifId	notifId;	/**< Notification id. */
	char *	owner;	/**< Identification of the job owner (certificate subject). */
	char *	dest_host;	/**< Hostname the notification is sent to. */
	uint16_t	dest_port;	/**< Port number the notification is sent to. */
	int	expires;	/**< When the notification expires */
	char *	jobstat;	/**< Status of the job (the notification content). */
} edg_wll_NotificationEvent;

/**
* \typedef edg_wll_ResourceUsageEvent
* structure definition for ResourceUsage event 
*/
typedef struct _edg_wll_ResourceUsageEvent {
_EDG_WLL_EVENT_COMMON
	char *	resource;	/**< Resource's name. */
	double	quantity;	/**< Resources's quantity (how much). */
	char *	unit;	/**< Units (sec, kB, etc.). */
} edg_wll_ResourceUsageEvent;

/**
* \typedef edg_wll_ReallyRunningEvent
* structure definition for ReallyRunning event 
*/
typedef struct _edg_wll_ReallyRunningEvent {
_EDG_WLL_EVENT_COMMON
	char *	wn_seq;	/**< Sequence code on the worker node. */
} edg_wll_ReallyRunningEvent;

/**
* \typedef edg_wll_SuspendEvent
* structure definition for Suspend event 
*/
typedef struct _edg_wll_SuspendEvent {
_EDG_WLL_EVENT_COMMON
	char *	reason;	/**< Reason for the suspend. */
} edg_wll_SuspendEvent;

/**
* \typedef edg_wll_ResumeEvent
* structure definition for Resume event 
*/
typedef struct _edg_wll_ResumeEvent {
_EDG_WLL_EVENT_COMMON
	char *	reason;	/**< Reason for the resume. */
} edg_wll_ResumeEvent;

/**
* \typedef edg_wll_CollectionStateEvent
* structure definition for CollectionState event 
*/
typedef struct _edg_wll_CollectionStateEvent {
_EDG_WLL_EVENT_COMMON
	char *	state;	/**< New collection state. */
	int	done_code;	/**< In case of (state == Done) contains done code  */
	char *	histogram;	/**< User readable histogram; useful for debugging. */
	edg_wlc_JobId	child;	/**< JobId of subjob, which triggered the state change.	 */
	char *	child_event;	/**< Event which triggered the state change.	 */
} edg_wll_CollectionStateEvent;

/**
* \typedef edg_wll_PBSQueuedEvent
* structure definition for PBSQueued event 
*/
typedef struct _edg_wll_PBSQueuedEvent {
_EDG_WLL_EVENT_COMMON
	char *	queue;	/**< Queue name */
	char *	owner;	/**< Job owner */
	char *	name;	/**< Job name */
} edg_wll_PBSQueuedEvent;

/**
* \typedef edg_wll_PBSMatchEvent
* structure definition for PBSMatch event 
*/
typedef struct _edg_wll_PBSMatchEvent {
_EDG_WLL_EVENT_COMMON
	char *	dest_host;	/**< Aka exec_host */
} edg_wll_PBSMatchEvent;

/**
* \typedef edg_wll_PBSPendingEvent
* structure definition for PBSPending event 
*/
typedef struct _edg_wll_PBSPendingEvent {
_EDG_WLL_EVENT_COMMON
	char *	reason;	/**< Reasons of job pendation or errors */
} edg_wll_PBSPendingEvent;

/**
* \typedef edg_wll_PBSRunEvent
* structure definition for PBSRun event 
*/
typedef struct _edg_wll_PBSRunEvent {
_EDG_WLL_EVENT_COMMON
	char *	scheduler;	/**< Scheduler ID */
	char *	dest_host;	/**< Where to run the job */
	int	pid;	/**< Actual process ID */
} edg_wll_PBSRunEvent;

/**
* \typedef edg_wll_PBSRerunEvent
* structure definition for PBSRerun event 
*/
typedef struct _edg_wll_PBSRerunEvent {
_EDG_WLL_EVENT_COMMON
} edg_wll_PBSRerunEvent;

/**
* \typedef edg_wll_PBSDoneEvent
* structure definition for PBSDone event 
*/
typedef struct _edg_wll_PBSDoneEvent {
_EDG_WLL_EVENT_COMMON
	int	exit_status;	/**< Exit status */
} edg_wll_PBSDoneEvent;

/**
* \typedef edg_wll_PBSDequeuedEvent
* structure definition for PBSDequeued event 
*/
typedef struct _edg_wll_PBSDequeuedEvent {
_EDG_WLL_EVENT_COMMON
} edg_wll_PBSDequeuedEvent;

/**
* \typedef edg_wll_PBSResourceUsageEvent
* structure definition for PBSResourceUsage event 
*/
typedef struct _edg_wll_PBSResourceUsageEvent {
_EDG_WLL_EVENT_COMMON
	enum edg_wll_PBSResourceUsageUsage	usage;	/**< Type of record */
	char *	name;	/**< Name of resource */
	double	quantity;	/**< The quantity */
	char *	unit;	/**< Units (sec, kB, etc.) */
} edg_wll_PBSResourceUsageEvent;

/**
* \typedef edg_wll_PBSErrorEvent
* structure definition for PBSError event 
*/
typedef struct _edg_wll_PBSErrorEvent {
_EDG_WLL_EVENT_COMMON
	char *	error_desc;	/**< Error reason */
} edg_wll_PBSErrorEvent;

/**
* \typedef edg_wll_CondorMatchEvent
* structure definition for CondorMatch event 
*/
typedef struct _edg_wll_CondorMatchEvent {
_EDG_WLL_EVENT_COMMON
	char *	owner;	/**< Owner */
	char *	dest_host;	/**< Matched host */
	char *	preempting;	/**< Preempting */
} edg_wll_CondorMatchEvent;

/**
* \typedef edg_wll_CondorRejectEvent
* structure definition for CondorReject event 
*/
typedef struct _edg_wll_CondorRejectEvent {
_EDG_WLL_EVENT_COMMON
	char *	owner;	/**< Owner */
	enum edg_wll_CondorRejectStatus_code	status_code;	/**< Reason code for the rejection of the job */
} edg_wll_CondorRejectEvent;

/**
* \typedef edg_wll_CondorShadowStartedEvent
* structure definition for CondorShadowStarted event 
*/
typedef struct _edg_wll_CondorShadowStartedEvent {
_EDG_WLL_EVENT_COMMON
	char *	shadow_host;	/**< Shadow host */
	uint16_t	shadow_port;	/**< Shadow port */
	int	shadow_pid;	/**< PID of shadow process */
	char *	shadow_status;	/**< Shadow status */
} edg_wll_CondorShadowStartedEvent;

/**
* \typedef edg_wll_CondorShadowExitedEvent
* structure definition for CondorShadowExited event 
*/
typedef struct _edg_wll_CondorShadowExitedEvent {
_EDG_WLL_EVENT_COMMON
	int	shadow_pid;	/**< PID of shadow process */
	int	shadow_exit_status;	/**< Exit status of shadow process */
} edg_wll_CondorShadowExitedEvent;

/**
* \typedef edg_wll_CondorStarterStartedEvent
* structure definition for CondorStarterStarted event 
*/
typedef struct _edg_wll_CondorStarterStartedEvent {
_EDG_WLL_EVENT_COMMON
	int	starter_pid;	/**< PID of starter process */
	char *	universe;	/**< Condor Universe */
} edg_wll_CondorStarterStartedEvent;

/**
* \typedef edg_wll_CondorStarterExitedEvent
* structure definition for CondorStarterExited event 
*/
typedef struct _edg_wll_CondorStarterExitedEvent {
_EDG_WLL_EVENT_COMMON
	int	starter_pid;	/**< PID of starter process */
	int	starter_exit_status;	/**< Exit status of starter process */
	int	job_pid;	/**< PID of running job */
	int	job_exit_status;	/**< Job exit status */
} edg_wll_CondorStarterExitedEvent;

/**
* \typedef edg_wll_CondorResourceUsageEvent
* structure definition for CondorResourceUsage event 
*/
typedef struct _edg_wll_CondorResourceUsageEvent {
_EDG_WLL_EVENT_COMMON
	enum edg_wll_CondorResourceUsageUsage	usage;	/**< Type of record */
	char *	name;	/**< Name of resource */
	double	quantity;	/**< The quantity */
	char *	unit;	/**< Units (sec, kB, etc.) */
} edg_wll_CondorResourceUsageEvent;

/**
* \typedef edg_wll_CondorErrorEvent
* structure definition for CondorError event 
*/
typedef struct _edg_wll_CondorErrorEvent {
_EDG_WLL_EVENT_COMMON
	char *	error_desc;	/**< Error reason */
} edg_wll_CondorErrorEvent;

#undef _EDG_WLL_EVENT_COMMON


/**
 * \union edg_wll_Event
 * \brief All event types union
 */
glite_lb_padded_union(_edg_wll_Event,30,
        edg_wll_EventCode           type; /* it is probably never used */
        edg_wll_AnyEvent            any;
	edg_wll_TransferEvent	transfer;
	edg_wll_AcceptedEvent	accepted;
	edg_wll_RefusedEvent	refused;
	edg_wll_EnQueuedEvent	enQueued;
	edg_wll_DeQueuedEvent	deQueued;
	edg_wll_HelperCallEvent	helperCall;
	edg_wll_HelperReturnEvent	helperReturn;
	edg_wll_RunningEvent	running;
	edg_wll_ResubmissionEvent	resubmission;
	edg_wll_DoneEvent	done;
	edg_wll_CancelEvent	cancel;
	edg_wll_AbortEvent	abort;
	edg_wll_ClearEvent	clear;
	edg_wll_PurgeEvent	purge;
	edg_wll_MatchEvent	match;
	edg_wll_PendingEvent	pending;
	edg_wll_RegJobEvent	regJob;
	edg_wll_ChkptEvent	chkpt;
	edg_wll_ListenerEvent	listener;
	edg_wll_CurDescrEvent	curDescr;
	edg_wll_UserTagEvent	userTag;
	edg_wll_ChangeACLEvent	changeACL;
	edg_wll_NotificationEvent	notification;
	edg_wll_ResourceUsageEvent	resourceUsage;
	edg_wll_ReallyRunningEvent	reallyRunning;
	edg_wll_SuspendEvent	suspend;
	edg_wll_ResumeEvent	resume;
	edg_wll_CollectionStateEvent	collectionState;
	edg_wll_PBSQueuedEvent	PBSQueued;
	edg_wll_PBSMatchEvent	PBSMatch;
	edg_wll_PBSPendingEvent	PBSPending;
	edg_wll_PBSRunEvent	PBSRun;
	edg_wll_PBSRerunEvent	PBSRerun;
	edg_wll_PBSDoneEvent	PBSDone;
	edg_wll_PBSDequeuedEvent	PBSDequeued;
	edg_wll_PBSResourceUsageEvent	PBSResourceUsage;
	edg_wll_PBSErrorEvent	PBSError;
	edg_wll_CondorMatchEvent	CondorMatch;
	edg_wll_CondorRejectEvent	CondorReject;
	edg_wll_CondorShadowStartedEvent	CondorShadowStarted;
	edg_wll_CondorShadowExitedEvent	CondorShadowExited;
	edg_wll_CondorStarterStartedEvent	CondorStarterStarted;
	edg_wll_CondorStarterExitedEvent	CondorStarterExited;
	edg_wll_CondorResourceUsageEvent	CondorResourceUsage;
	edg_wll_CondorErrorEvent	CondorError;
)
typedef union _edg_wll_Event edg_wll_Event;


/**
 * Initialise an event structure
 * \return pointer to initialised event structure
 */
extern edg_wll_Event *edg_wll_InitEvent(edg_wll_EventCode eventcode);


/**
 * Free the contents of event structure
 * \param[in] event 		structure to be freed
 * \warning As event structures are likely to be allocated in arrays,
 *      the structure itself is not freed.
 *      Its the responsibility of the caller to call free(event)
 *      if appropriate.
 */
void edg_wll_FreeEvent(
	edg_wll_Event * event
);

/*
 *@} end of group
 */

#ifdef __cplusplus
}
#endif

#endif /* __EDG_WORKLOAD_LOGGING_CLIENT_EVENTS_H__ */
